<?php
session_start();

//If the user is not logged in, redirect the user to login.html page
if(!isset($_SESSION['user_session']))
{
  header("Location: login.html"); 
}

include_once 'db.php';

$stmt = $db_con->prepare("SELECT * FROM users WHERE user_id=:uid");
$stmt->execute(array(":uid"=>$_SESSION['user_session']));
$row=$stmt->fetch(PDO::FETCH_ASSOC);

?>
<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <link
      rel="stylesheet"
      href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css"
    />
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.12.4/jquery.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/js/bootstrap.min.js"></script>
    <style>
      body {
        font-family: Arial, sans-serif;
        background-color: #f0f0f0;
        display: flex;
        justify-content: center;
        align-items: center;
        min-height: 100vh;
        margin: 80;
      }
      .login-container {
        display: flex;
        flex-direction: column;
        align-items: center;
        background-color: #fff;
        padding: 40px;
        border-radius: 8px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
      }
      .form-container {
        display: flex;
        flex-direction: column;
        align-items: center;
        margin-bottom: 15px;
        width: 100%;
      }
      .form-container label {
        display: flex;
        margin-bottom: 5px;
      }
      .form-container input,
      .form-container select {
        width: 100%;
        padding: 10px;
        border: 1px solid #ccc;
        border-radius: 16px;
      }
      .btn-container {
        display: flex;
        justify-content: center;
      }
      .btn-login {
        width: 60%;
        padding: 10px;
        background-color: #2abe4a;
        color: white;
        border: none;
        border-radius: 18px;
        cursor: pointer;
        margin-bottom: 10px;
      }
      .btn-login:hover {
        background-color: #218838;
      }
      .split {
        display: flex;
        flex-direction: column;
        padding: 10px;
      }
      .wholeform {
        display: flex;
        flex-direction: row;
      }
      .form-container textarea {
        width: 100%;
        padding: 10px;
        border: 1px solid #ccc;
        border-radius: 16px;
      }

      table {
        width: 100%;
        border-collapse: collapse;
        margin-top: 20px;
   }
      table,
      th,
      td {
        border: 1px solid #ccc;
      }
      th,
      td {
        padding: 10px;
        text-align: left;
      }
      th {
        background-color: #f8f8f8;
      }
    </style>
  </head>
  <body>
    <div class="login-container">
      <form id="event_form" class="form-horizontal" action="#" method="post">
        <h2>Create an Event</h2>
        <fieldset>
          <div class="wholeform">
            <div class="split">
              <div class="form-container">
                <label for="eventtitle">Title</label>
                <input type="text" id="eventtitle" name="eventtitle" required />
              </div>
              <div class="form-container">
                <label for="org">Organization</label>
                <input type="text" id="org" name="org" required />
              </div>
              <div class="form-container">
                <label for="reason">Description</label>
                <textarea id="reason" name="reason" required></textarea>
              </div>
              <div class="form-container">
                <label for="expected">Expected Participants</label>
                <input
                  type="number"
                  id="expected"
                  name="expected"
                  min="1"
                  required
                />
              </div>
            </div>

            <div class="split">
              <div class="form-container">
                <label for="eventdate">Date</label>
                <input type="date" id="eventdate" name="eventdate" required />
              </div>
              <div class="form-container">
                <label for="eventtime">Time</label>
                <input type="time" id="eventtime" name="eventtime" required />
              </div>

              <div class="form-container">
                <label for="email">Organizer Email</label>
                <input type="email" id="email" name="email" required />
              </div>
              <div class="form-container">
                <label for="place">Room Number</label>
                <select name="place" id="place" required>
                  <option value="">Select a room</option>
                  <option value="STC101">Schollmaier 101</option>
                  <option value="STC102">Schollmaier 102</option>
                  <option value="STC103">Schollmaier 103</option>
                  <option value="STC104">Schollmaier 104</option>

                  <option value="MCF101">McFadden 101</option>
                  <option value="MCF102">McFadden 102</option>
                  <option value="MCF103">McFadden 103</option>
                  <option value="MCF104">McFadden 104</option>

                  <option value="EJW101">Library 101</option>
                  <option value="EJW102">Library 102</option>
                  <option value="EJW103">Library 103</option>
                  <option value="EJW104">Library 104</option>

                  <option value="AMB101">Armstrong-Mabee 101</option>
                  <option value="AMB102">Armstrong-Mabee 102</option>
                  <option value="AMB103">Armstrong-Mabee 103</option>
                  <option value="AMB104">Armstrong-Mabee 104</option>
                </select>
              </div>
            </div>
          </div>

          <div class="btn-container">
            <button type="submit" class="btn-login" name="submit">
              Submit Event
            </button>
          </div>
        </fieldset>
      </form>

      <span id="new_event"></span>
      <div id="event_list"></div>
      <p>Submitting an event does not guarantee its creation.</p>
      <p>All events must be approved first!</p>
      <p><a href="index.html">Home</a></p>
    </div>

    <script>
      $(document).ready(function () {
        const url = "get_events.php";
        const $list = $("#event_list");
        const $status = $("#new_event");

        $("#event_form").on("submit", function (e) {
          e.preventDefault();

          const eventData = $(this).serialize();

          $.ajax({
            type: "POST",
            url: url,
            data: { command: "insert_event", event_data: eventData },
            beforeSend: function () {
              $status.html("Submitting event...");
            },
            success: function (response) {
              const res = JSON.parse(response);
              $status.html("Event submitted successfully!");
              $("#event_form")[0].reset();
              fetchEvents();
            },
            error: function () {
              $status.html("Failed to submit event.");
            },
          });
        });
      });
    </script>
  </body>
</html>